@@ -531,6 +531,9 @@ var app = new Vue({
         },
         operations: function () {
             return this.collections[ this.currentCollection ].operations;
+        },
+        schema: function () {
+            return this.collections[ this.currentCollection ].operations.get.schema || {};
         }
     },
     watch: {
