@@ -1,5 +1,5 @@
 package Yancy;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 # ABSTRACT: A simple CMS for administrating data
 
 #pod =head1 SYNOPSIS
@@ -44,7 +44,7 @@ our $VERSION = '0.012';
 #pod Mojo::Pg|Yancy::Backend::Pg>, L<MySQL via
 #pod Mojo::mysql|Yancy::Backend::Mysql>, L<SQLite via
 #pod Mojo::SQLite|Yancy::Backend::Sqlite>, and L<DBIx::Class, a Perl
-#pod ORM|Yancy::Backend::DBIC>
+#pod ORM|Yancy::Backend::Dbic>
 #pod
 #pod =head2 Standalone App
 #pod
@@ -469,7 +469,7 @@ Yancy - A simple CMS for administrating data
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -509,7 +509,7 @@ Yancy can manage data in multiple databases using different backends
 Mojo::Pg|Yancy::Backend::Pg>, L<MySQL via
 Mojo::mysql|Yancy::Backend::Mysql>, L<SQLite via
 Mojo::SQLite|Yancy::Backend::Sqlite>, and L<DBIx::Class, a Perl
-ORM|Yancy::Backend::DBIC>
+ORM|Yancy::Backend::Dbic>
 
 =head2 Standalone App
 
@@ -901,7 +901,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Mohammad S Anwar William Lindley
+=for stopwords Mohammad S Anwar mohawk2 William Lindley
 
 =over 4
 
@@ -911,6 +911,10 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =item *
 
+mohawk2 <mohawk2@users.noreply.github.com>
+
+=item *
+
 William Lindley <wlindley@wlindley.com>
 
 =back
